stsynphot
=========

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3588574.svg
   :target: https://doi.org/10.5281/zenodo.3588574

.. image:: https://readthedocs.org/projects/stsynphot/badge/?version=latest
    :target: http://stsynphot.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://dev.azure.com/spacetelescope/stsynphot_refactor/_apis/build/status/spacetelescope.stsynphot_refactor?branchName=master
    :target: https://dev.azure.com/spacetelescope/stsynphot_refactor/_build/latest?definitionId=10&branchName=master
    :alt: Build Status

.. image:: https://codecov.io/gh/spacetelescope/stsynphot_refactor/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/spacetelescope/stsynphot_refactor
    :alt: Coverage results

This is a replacement for IRAF STSDAS SYNPHOT and ASTROLIB PYSYNPHOT, utilizing Astropy
covering instrument specific portions of the old packages for HST (and soon JWST).
